==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CategoryXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
import { CategoryXAxisDescription } from "./CategoryXAxisDescription";
/**
 * @hidden
 */
var CategoryXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryXAxisDescriptionMetadata, _super);
    function CategoryXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryXAxisDescriptionMetadata.b = function (a) {
        if (CategoryXAxisDescriptionMetadata.a == null) {
            CategoryXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryXAxisDescriptionMetadata.c(CategoryXAxisDescriptionMetadata.a);
        }
        if (a.j(CategoryXAxisDescriptionMetadata.a)) {
            return;
        }
        a.y(CategoryXAxisDescriptionMetadata.a);
    };
    CategoryXAxisDescriptionMetadata.c = function (a) {
        CategoryAxisBaseDescriptionMetadata.c(a);
        a.item("ZoomMaximumCategoryRange", "Number:double");
        a.item("ZoomMaximumItemSpan", "Number:double");
        a.item("ZoomToCategoryRange", "Number:double");
        a.item("ZoomToCategoryStart", "Number:double");
        a.item("ZoomToItemSpan", "Number:double");
        a.item("Interval", "Number:double");
        a.item("ActualInterval", "Number:double");
        a.item("MinorInterval", "Number:double");
        a.item("ActualMinorInterval", "Number:double");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    CategoryXAxisDescriptionMetadata.d = function (a) {
        CategoryXAxisDescriptionMetadata.b(a);
        a.aa("CategoryXAxis", function () { return new CategoryXAxisDescription(); });
        a.z("CategoryXAxis", CategoryXAxisDescriptionMetadata.a);
    };
    CategoryXAxisDescriptionMetadata.$t = markType(CategoryXAxisDescriptionMetadata, 'CategoryXAxisDescriptionMetadata');
    CategoryXAxisDescriptionMetadata.a = null;
    return CategoryXAxisDescriptionMetadata;
}(Base));
export { CategoryXAxisDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/CategoryXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
import { CategoryXAxisDescription } from "./CategoryXAxisDescription";
/**
 * @hidden
 */
var CategoryXAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryXAxisDescriptionMetadata, _super);
    function CategoryXAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryXAxisDescriptionMetadata.b = function (a) {
        if (CategoryXAxisDescriptionMetadata.a == null) {
            CategoryXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryXAxisDescriptionMetadata.c(CategoryXAxisDescriptionMetadata.a);
        }
        if (a.k(CategoryXAxisDescriptionMetadata.a)) {
            return;
        }
        a.aa(CategoryXAxisDescriptionMetadata.a);
    };
    CategoryXAxisDescriptionMetadata.c = function (a) {
        CategoryAxisBaseDescriptionMetadata.c(a);
        a.item("ZoomMaximumCategoryRange", "Number:double");
        a.item("ZoomMaximumItemSpan", "Number:double");
        a.item("ZoomToCategoryRange", "Number:double");
        a.item("ZoomToCategoryStart", "Number:double");
        a.item("ZoomToItemSpan", "Number:double");
        a.item("Interval", "Number:double");
        a.item("ActualInterval", "Number:double");
        a.item("MinorInterval", "Number:double");
        a.item("ActualMinorInterval", "Number:double");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    CategoryXAxisDescriptionMetadata.d = function (a) {
        CategoryXAxisDescriptionMetadata.b(a);
        a.ac("CategoryXAxis", function () { return new CategoryXAxisDescription(); });
        a.ab("CategoryXAxis", CategoryXAxisDescriptionMetadata.a);
    };
    CategoryXAxisDescriptionMetadata.$t = markType(CategoryXAxisDescriptionMetadata, 'CategoryXAxisDescriptionMetadata');
    CategoryXAxisDescriptionMetadata.a = null;
    return CategoryXAxisDescriptionMetadata;
}(Base));
export { CategoryXAxisDescriptionMetadata };
